
public class Reservation {

	private final String personName;
	private final int startSeat;
	private final int howManySeats;

	/**
	 * Create a Reservation.
	 */
	public Reservation(String name, int start, int howMany) {
		this.personName = name;
		this.startSeat = start;
		this.howManySeats = howMany;
	}

	/**
	 * Get the name of the person who holds this reservation.
	 */
	public String getName() {
		return personName;
	}

	/**
	 * Get the first seat number in this reservation.
	 */
	public int getFirstSeat() {
		return startSeat;
	}

	/**
	 * Get the last seat number in this reservation.
	 */
	public int getLastSeat() {
		return startSeat + howManySeats - 1;
	}

	/**
	 * Get the number of seats in this reservation.
	 */
	public int getNumberOfSeats() {
		return howManySeats;
	}

	public String toString() {
		return "[Reservation for " + personName + ": seats " + startSeat
						+ " through " + (startSeat + howManySeats - 1) + "]";
	}

	public boolean equals(Object o) {
		if (this == o) {
			return true;
		}

		if (!(o instanceof Reservation)) {
			return false;
		}

		Reservation r = (Reservation) o;

		if (personName.equals(r.personName) && startSeat == r.startSeat
						&& howManySeats == r.howManySeats) {
			return true;
		}

		return false;
	}

	public int hashCode() {
		return personName.hashCode() ^ startSeat ^ howManySeats;
	}
}
