
import java.awt.*;
import java.awt.Dimension;
import java.awt.Graphics;
import javax.swing.JPanel;

/**
 * A TheaterDisplay is a live-updating display of the current seating chart.
 */
public class TheaterDisplay extends JPanel {

	private final Theater theater;
	private final int numseats;
	private final int SEAT_HEIGHT = 20;
	private final int SEAT_WIDTH = 400;

	public TheaterDisplay(Theater t) {
		this.theater = t;
		this.numseats = theater.getSize();
	}

	public Dimension getPreferredSize() {
		return new Dimension(SEAT_WIDTH, SEAT_HEIGHT * numseats);
	}

	/**
	 * Call this method to refresh the live display of the seats.
	 */
	public void refresh() {
		super.repaint();
	}

	public void paintComponent(Graphics g) {
		super.paintComponent(g);

		for (int x = 0; x < numseats; x++) {
			Reservation r = theater.getReservationForSeat(x);
			if (r == null) {
				// seat is open, paint green
				g.setColor(Color.green);
			} else {
				// seat is full, paint red
				g.setColor(Color.red);
			}

			g.fillRect(0, SEAT_HEIGHT * x, SEAT_WIDTH, SEAT_HEIGHT);
			g.setColor(Color.black);
			g.setFont(new Font("Arial", Font.PLAIN, 12));
			g.drawString(String.valueOf(x), 0, SEAT_HEIGHT * (x + 1) - 3);	
			g.drawString(r == null ? "(available)" : r.toString(), 20, SEAT_HEIGHT * (x + 1) - 3);
		}
	}
}
